# The contents of this file are subject to the Mozilla Public
# License Version 1.1 (the "License"); you may not use this file
# except in compliance with the License. You may obtain a copy of
# the License at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS
# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
# implied. See the License for the specific language governing
# rights and limitations under the License.
#
# The Original Code is BesserWisser version 2.0.
#
# The Initial Developer of the Original Code is European Environment
# Agency (EEA).  Portions created by Finsiel Romania are
# Copyright (C) European Environment Agency.  All
# Rights Reserved.
#
# Contributor(s):
# Soren Roug, EEA
# Miruna Badescu, Finsiel Romania


""" Module for email sending
"""

# Python imports
import time
import smtplib
import MimeWriter
import mimetools
import cStringIO

# Zope imports
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from DateTime import DateTime

# Product imports

class EmailManager:
    """ EmailManager """

    #security stuff
    security = ClassSecurityInfo()

    security.declarePrivate('__emSendEmail')
    def __emSendEmail(self, p_to, p_from, p_subject, p_content):
        """Sends an email"""
        try:
            l_message = self.__emCreateEmail(p_to, p_from, p_subject, p_content)
            server = smtplib.SMTP(self.servername, self.serverport)
            server.sendmail(p_from, p_to, l_message)
            server.quit()
            return 1
        except:
            return 0

    security.declarePrivate('__emCreateEmail')
    def __emCreateEmail(self, p_to, p_from, p_subject, p_content):
        """Create a mime-message that will render as text"""
        l_out = cStringIO.StringIO() # output buffer for our message
        l_writer = MimeWriter.MimeWriter(l_out)
        # set up some basic headers
        l_writer.addheader("From", p_from)
        l_writer.addheader("To", p_to)
        l_writer.addheader("Date", time.strftime("%a, %d %b %Y %H:%M:%S +0000", time.gmtime()))
        l_writer.addheader("Subject", p_subject)
        l_writer.addheader("MIME-Version", "1.0")
        # start the multipart section of the message
        l_writer.startmultipartbody("alternative")
        l_writer.flushheaders()
        # the plain text section
        l_subpart = l_writer.nextpart()
        l_pout = l_subpart.startbody("text/plain", [("charset", 'iso-8859-1')])
        l_pout.write(p_content)
        #close your writer and return the message body
        l_writer.lastpart()
        l_msg = l_out.getvalue()
        l_out.close()
        return l_msg


    security.declarePublic('registrationEmail')
    def registrationEmail(self, p_to, p_from, p_user_fullname, p_userid, p_password, p_location):
        """ Sends an email to confirm expert registration """
        l_subject = "Complete EnviroExperts registration"
        l_content = """Dear %s,

Welcome to EnviroExperts!

Your registration information are:

Expert id is: %s
Password: %s

Location: %s

EnviroExperts Team
""" % (p_user_fullname, p_userid, p_password, p_location)
        return self.__emSendEmail(p_to, p_from, l_subject, l_content)


    security.declarePublic('sendPasswordbyEmail')
    def sendPasswordbyEmail(self, p_to, p_from, p_subject, p_userid, p_password, p_location):
        """ Sends expert's password by email """
        l_subject = "Information about " + p_subject
        l_content = """Dear expert,

Your user-id is: %s with password: %s

Location: %s

EnviroExperts Team
""" % (p_userid, p_password, p_location)
        return self.__emSendEmail(p_to, p_from, l_subject, l_content)


    security.declarePublic('newQuestionEmail')
    def newQuestionEmail(self, p_to, p_from, p_expert_fullname, p_linktofollow):
        """ Send an email when a new question is asked """
        l_subject = "New Question for you on EnviroExperts"
        l_content = """Dear %s,

A new question has been posted for you. Please login to EnviroExperts by following this link:

%s

and click on the "answer questions" tab.

best regards

EnviroExperts Team

""" % (p_expert_fullname, p_linktofollow)
        return self.__emSendEmail(p_to, p_from, l_subject, l_content)


    security.declarePublic('answeredQuestionEmail')
    def answeredQuestionEmail(self, p_to, p_from, p_question_inquirer, p_question_headline, p_linktofollow):
        """ Send an email when a question is answered """
        l_subject = "Your Question on EnviroExperts is answered"
        l_content = """Dear %s,

Your question with headline %s has been answered, you can view it following this link:

%s

best regards

EnviroExperts Team

""" % (p_question_inquirer, p_question_headline, p_linktofollow)
        return self.__emSendEmail(p_to, p_from, l_subject, l_content)


    security.declarePublic('mailToExperts')
    def mailToExperts(self, p_to, p_from, p_message):
        """ Send an email to a list of experts """
        l_subject = "Notification from EnviroExperts"
        return self.__emSendEmail(p_to, p_from, l_subject, p_message)

InitializeClass(EmailManager)
