# The contents of this file are subject to the Mozilla Public
# License Version 1.1 (the "License"); you may not use this file
# except in compliance with the License. You may obtain a copy of
# the License at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS
# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
# implied. See the License for the specific language governing
# rights and limitations under the License.
#
# The Original Code is BesserWisser version 2.0.
#
# The Initial Developer of the Original Code is European Environment
# Agency (EEA).  Portions created by Finsiel Romania are
# Copyright (C) European Environment Agency.  All
# Rights Reserved.
#
# Contributor(s):
# Soren Roug, EEA
# Miruna Badescu, Finsiel Romania


""" The Experts Folder is meant to keep Expert objects. The name is fixed, so it can be 
    only one inside a 'BesserWisser'.'Expert Category's and 'Expert Question's will 
    search for experts in here.
"""

# Python imports

# Zope imports
from OFS.Folder import Folder
import Globals
from AccessControl import ClassSecurityInfo
from AccessControl.Permissions import view_management_screens, view
from Products import meta_types

# Product imports
from Utils import Utils
from ExpertData import ExpertFormData
import Expert
import Resources

manage_addExpertsFolderForm = Globals.DTMLFile('dtml/ExpertsFolder_add', globals())
def manage_addExpertsFolder(self, title, REQUEST=None):
    """Adds a new Experts Folder object"""
    id = Resources.EXPERTS_FOLDER_DEFAULT_ID
    ob = ExpertsFolder(id, title)
    self._setObject(id, ob)
    if REQUEST is not None:
        return self.manage_main(self, REQUEST, update_menu=1)

class ExpertsFolder(Folder, Utils):
    """ ExpertsFolder class - container for 'Expert' objects """

    meta_type = Resources.METATYPE_EXPERTS_FOLDER
    icon = 'misc_/BesserWisser/expert.gif'

    manage_options = Folder.manage_options

    _properties = (
        {'id':'title', 'type':'string', 'mode':'w'},
    )

    security = ClassSecurityInfo()

    def __init__(self, id, title):
        """ ExpertsFolder constructor """
        self.id = id
        self.title = title
        Utils.__dict__['__init__'](self)

    def all_meta_types( self, interfaces=None ):
        """ Checks if the legal products are actually installed in Zope """
        y = [
            {'name': Resources.METATYPE_EXPERT, 'action': 'manage_addExpertForm'}
        ]
        additional_meta_types = []
        for x in meta_types:
            if x['name'] in additional_meta_types:
                y.append(x)
        return y

    security.declarePublic('getExperts')
    def getExperts(self):
        """ """
        return self.objectValues(Resources.METATYPE_EXPERT)

    security.declarePublic('getTopExperts')
    def getTopExperts(self, p_howmany):
        """ """
        l_experts = self.objectValues(Resources.METATYPE_EXPERT)
        l_experts_ratings = map(lambda x: x.averageRating_Timelineness()[1], l_experts)
        l_tuples = zip(l_experts_ratings, l_experts)
        l_tuples.sort()
        l_tuples.reverse()
        l_experts = map(lambda x: x[1], l_tuples)
        return l_experts[:p_howmany]

    security.declarePrivate('existsExpertEmail')
    def existsExpertEmail(self, p_email):
        """ Checks if there is an expert with the given email """
        for l_expert in self.getExperts():
            if l_expert.Email == p_email:
                return 1
        return 0

    security.declarePrivate('getEmptyExpertFormData')
    def getEmptyExpertFormData(self):
        """ Returns an ExpertData object """
        return ExpertFormData('', '', '', '', ['EN'], '', '', '', [], '', '', '', '', '', '')

    # Subobjects
    security.declareProtected(view, 'manage_addExpertForm')
    manage_addExpertForm = Expert.manage_addExpertForm

    security.declareProtected(view, 'manage_addExpert')
    manage_addExpert = Expert.manage_addExpert

    security.declareProtected(view, 'manage_addExpertStep2')
    manage_addExpertStep2 = Expert.manage_addExpertStep2

    security.declarePublic('manage_validateValuesStep1')
    manage_validateValuesStep1 = Expert.manage_validateValuesStep1

    security.declareProtected(view, 'index_html')
    index_html = Globals.DTMLFile('dtml/ExpertsFolder_index',globals())

Globals.InitializeClass(ExpertsFolder)
