""" $Id: LanguagesManager.py,v 1.3 2004/01/09 16:42:14 finrocvs Exp $ """

# Python imports

# Zope imports
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

# Product imports

class Language:
    """Defines a Language.
        - id: id
        - name: language's name
        - encoding: 
    """

    def __init__(self, p_id, p_name, p_encoding):
        """Init a new Language object"""
        self.id = p_id
        self.name = p_name
        self.encoding = p_encoding


class LanguagesManager:
    """ This class is responsable with languages management.
        All the data is stored in a dictionary like structure:
            - key: language id
            - value: language object
    """

    def __init__(self):
        """Constructor"""
        self.__languages = {}
        self.__default_language = ''

    #security stuff
    security = ClassSecurityInfo()

    security.declarePrivate('__createLanguage')
    def __createLanguage(self, p_id, p_name, p_encoding):
        """Add a new object"""
        obj = Language(p_id, p_name, p_encoding)
        self.__languages[p_id] = obj

    security.declarePrivate('__modifyLanguage')
    def __modifyLanguage(self, p_id, p_name, p_encoding):
        """Modify object"""
        try:
            obj = self.__languages[p_id]
        except:
            pass
        else:
            obj.name = p_name
            obj.encoding = p_encoding

    security.declarePrivate('__deleteLanguage')
    def __deleteLanguage(self, p_id):
        """Delete an object"""
        try:
            del(self.__languages[p_id])
        except:
            pass

    security.declarePrivate('getLanguagesList')
    def getLanguagesList(self):
        """Get a list with all languages"""
        try:
            return self.__languages.values()
        except:
            return []

    security.declarePrivate('getLanguagesNames')
    def getLanguagesNames(self):
        """Get a list with all languages names"""
        l_result = []
        try:
            for lan in self.__languages.values():
                l_result.append(lan.name)
            l_result.sort()
        except:
            pass
        return l_result

    security.declarePrivate('getLanguagesNamesToIds')
    def getLanguagesNamesToIds(self):
        """ Get a dictionary languages names as keys and languages ids as values """
        l_result = {}
        try:
            for lan in self.__languages.values():
                l_result[lan.name] = lan.id
        except:
            pass
        return l_result

    security.declarePrivate('getDefaultLanguage')
    def getDefaultLanguage(self):
        """Get a list with all languages"""
        return self.__default_language

    security.declarePrivate('getLanguage')
    def getLanguage(self, p_id):
        """Get a Language object"""
        try:
            return self.__languages[p_id]
        except:
            return None

    security.declarePublic('getLanguageName')
    def getLanguageName(self, p_id):
        """Get a Language name"""
        try:
            return self.__languages[p_id].name
        except:
            return ''

    security.declarePrivate('getLanguageEncoding')
    def getLanguageEncoding(self, p_id):
        """Get a Language encoding"""
        try:
            return self.__languages[p_id].encoding
        except:
            return ''

    security.declarePrivate('createLanguage')
    def createLanguage(self, p_id, p_name, p_encoding):
        """Create a new Language"""
        self.__createLanguage(p_id, p_name, p_encoding)
        self._p_changed = 1

    security.declarePrivate('modifyLanguage')
    def modifyLanguage(self, p_id, p_name, p_encoding):
        """Modify Language's properties"""
        self.__modifyLanguage(p_id, p_name, p_encoding)
        self._p_changed = 1

    security.declarePrivate('deleteLanguage')
    def deleteLanguage(self, p_ids):
        """Delete 1 or more Language objects"""
        for l_id in p_ids:
            self.__deleteLanguage(l_id)
        self._p_changed = 1

    security.declarePrivate('setDefaultLanguage')
    def setDefaultLanguage(self, p_id):
        """Set the default language"""
        self.__default_language = p_id
        self._p_changed = 1


InitializeClass(LanguagesManager)
